spacepy.toolbox.progressbar — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.progressbar

`spacepy.toolbox.` `progressbar`(count, blocksize, totalsize, text='Download Progress')

  print a progress bar with urllib.urlretrieve reporthook functionality

  Examples

      >>> import spacepy.toolbox as tb
      >>> import urllib
      >>> urllib.urlretrieve(config['psddata_url'], PSDdata_fname, reporthook=tb.progressbar)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »